<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>AptSearchPluginShortInputWidget</name>
    <message>
        <location filename="../src/plugins/aptplugin/aptsearchpluginshortinputwidget.ui" line="14"/>
        <source>Form1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/aptplugin/aptsearchpluginshortinputwidget.ui" line="26"/>
        <source>Search for pattern</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/aptplugin/aptsearchpluginshortinputwidget.ui" line="41"/>
        <source>Search the package database for the given expression</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/aptplugin/aptsearchpluginshortinputwidget.ui" line="44"/>
        <source>This searches the package names and descriptions for the given pattern. If you enter more than one word all words must be contained.&lt;br&gt;
You can search for phrases by using double quotes around the phrase. To enter patterns or phrases which should not appear in the package precede them with a minus (&apos;-&apos;).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/aptplugin/aptsearchpluginshortinputwidget.ui" line="52"/>
        <source>Clear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/aptplugin/aptsearchpluginshortinputwidget.ui" line="66"/>
        <source>Search the package descriptions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/aptplugin/aptsearchpluginshortinputwidget.ui" line="69"/>
        <source>Check this if you want to search in the package descriptions. The search will search the package name, the long description and the short description.&lt;br /&gt;If not checked only the package names will be searched.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/aptplugin/aptsearchpluginshortinputwidget.ui" line="72"/>
        <source>Search Descriptions</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AptSettingsWidget</name>
    <message>
        <location filename="../src/plugins/aptplugin/aptsettingswidget.ui" line="13"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/aptplugin/aptsettingswidget.ui" line="19"/>
        <source>The selected tool will be used to install/remove the selected packages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/aptplugin/aptsettingswidget.ui" line="22"/>
        <source>For package installation Debian Package Search relies on an external program. You can select wether to use apt or aptitude here.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/aptplugin/aptsettingswidget.ui" line="25"/>
        <source>Package Administration Tool</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/aptplugin/aptsettingswidget.ui" line="31"/>
        <source>apt-get</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/aptplugin/aptsettingswidget.ui" line="38"/>
        <source>aptitude</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>InstalledFilterWidget</name>
    <message>
        <location filename="../src/plugins/aptplugin/installedfilterwidget.ui" line="13"/>
        <source>Form1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/aptplugin/installedfilterwidget.ui" line="25"/>
        <source>Installed Filter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/aptplugin/installedfilterwidget.ui" line="32"/>
        <source>Search packages by installed state</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/aptplugin/installedfilterwidget.ui" line="35"/>
        <source>Search packages by installed state.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/aptplugin/installedfilterwidget.ui" line="39"/>
        <source>All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/aptplugin/installedfilterwidget.ui" line="44"/>
        <source>Installed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/aptplugin/installedfilterwidget.ui" line="49"/>
        <source>Upgradable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/aptplugin/installedfilterwidget.ui" line="54"/>
        <source>Not Installed</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NPlugin::AptActionPlugin</name>
    <message>
        <location filename="../src/plugins/aptplugin/aptactionplugin.cpp" line="42"/>
        <source>Update Apt-Package Database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/aptplugin/aptactionplugin.cpp" line="43"/>
        <source>Updates the package database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/aptplugin/aptactionplugin.cpp" line="48"/>
        <source>Reloads the package database from disk (e.g. if apt-get update was performed externally).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/aptplugin/aptactionplugin.cpp" line="54"/>
        <source>Copy Command Line for Installing Package to Clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/aptplugin/aptactionplugin.cpp" line="55"/>
        <location filename="../src/plugins/aptplugin/aptactionplugin.cpp" line="56"/>
        <source>Creates a command line to install the selected package, and copies it to the clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/aptplugin/aptactionplugin.cpp" line="60"/>
        <source>Install/Update Package</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/aptplugin/aptactionplugin.cpp" line="61"/>
        <location filename="../src/plugins/aptplugin/aptactionplugin.cpp" line="62"/>
        <source>Installs/updates the package</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/aptplugin/aptactionplugin.cpp" line="66"/>
        <source>Remove Package</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/aptplugin/aptactionplugin.cpp" line="67"/>
        <location filename="../src/plugins/aptplugin/aptactionplugin.cpp" line="68"/>
        <source>Removes the package</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/aptplugin/aptactionplugin.cpp" line="72"/>
        <source>Purge Package</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/aptplugin/aptactionplugin.cpp" line="73"/>
        <location filename="../src/plugins/aptplugin/aptactionplugin.cpp" line="74"/>
        <source>Removes package including configuration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/aptplugin/aptactionplugin.cpp" line="183"/>
        <source>Unable to launch command</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NPlugin::AptPluginContainer</name>
    <message>
        <location filename="../src/plugins/aptplugin/aptplugincontainer.cpp" line="199"/>
        <location filename="../src/plugins/aptplugin/aptplugincontainer.cpp" line="208"/>
        <source>Command not executed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/aptplugin/aptplugincontainer.cpp" line="199"/>
        <source>For an unknwon reason, the command could not be executed.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NPlugin::AptSearchPlugin</name>
    <message>
        <location filename="../src/plugins/aptplugin/aptsearchplugin.cpp" line="37"/>
        <source>Apt-Search Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/aptplugin/aptsearchplugin.cpp" line="38"/>
        <source>Performs a full text search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/aptplugin/aptsearchplugin.cpp" line="39"/>
        <source>This plugin can be used to search the packages for expressions.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/aptplugin/aptsearchplugin.cpp" line="137"/>
        <source>Delayed evaluation - waiting for further input</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/aptplugin/aptsearchplugin.cpp" line="147"/>
        <source>Performing full text search on package database</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NPlugin::AvailableVersionPlugin</name>
    <message>
        <location filename="../src/plugins/aptplugin/availableversionplugin.cpp" line="27"/>
        <source>Available Version Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/aptplugin/availableversionplugin.cpp" line="28"/>
        <location filename="../src/plugins/aptplugin/availableversionplugin.cpp" line="29"/>
        <source>Shows the version for the package available for download</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/aptplugin/availableversionplugin.h" line="65"/>
        <source>Available Version</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NPlugin::InstalledVersionPlugin</name>
    <message>
        <location filename="../src/plugins/aptplugin/installedversionplugin.cpp" line="25"/>
        <source>Installed Version Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/aptplugin/installedversionplugin.cpp" line="26"/>
        <location filename="../src/plugins/aptplugin/installedversionplugin.cpp" line="27"/>
        <source>Shows the version of the installed package in the package list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/aptplugin/installedversionplugin.h" line="63"/>
        <source>Installed Version</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NPlugin::PackageDescriptionPlugin</name>
    <message>
        <location filename="../src/plugins/aptplugin/packagedescriptionplugin.cpp" line="63"/>
        <location filename="../src/plugins/aptplugin/packagedescriptionplugin.h" line="91"/>
        <source>Description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/aptplugin/packagedescriptionplugin.cpp" line="189"/>
        <source>&lt;h3&gt;Package not found&lt;/h3&gt;&lt;p&gt;Could not find a valid description for the package &lt;b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/aptplugin/packagedescriptionplugin.cpp" line="191"/>
        <source>&lt;/b&gt; in the database.&lt;br&gt;This could mean either that you have selected a virtual package or that the package description  was not found for an unknown reason.&lt;/p&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/aptplugin/packagedescriptionplugin.cpp" line="217"/>
        <source>&lt;b&gt;Installed Version&lt;/b&gt;: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/aptplugin/packagedescriptionplugin.cpp" line="219"/>
        <source>&lt;b&gt;Available Version&lt;/b&gt;: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/aptplugin/packagedescriptionplugin.cpp" line="221"/>
        <source>&lt;b&gt;Available Version&lt;/b&gt;: not available&lt;br&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/aptplugin/packagedescriptionplugin.cpp" line="223"/>
        <source>&lt;b&gt;Essential&lt;/b&gt;: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/aptplugin/packagedescriptionplugin.cpp" line="227"/>
        <source>&lt;b&gt;Priority&lt;/b&gt;: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/aptplugin/packagedescriptionplugin.cpp" line="231"/>
        <source>&lt;b&gt;Section&lt;/b&gt;: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/aptplugin/packagedescriptionplugin.cpp" line="233"/>
        <source>&lt;b&gt;Section&lt;/b&gt;: not available&lt;br&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/aptplugin/packagedescriptionplugin.cpp" line="235"/>
        <source>&lt;b&gt;Installed Size&lt;/b&gt;: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/aptplugin/packagedescriptionplugin.cpp" line="237"/>
        <source>&lt;b&gt;Installed Size&lt;/b&gt;: not available&lt;br&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/aptplugin/packagedescriptionplugin.cpp" line="239"/>
        <source>&lt;b&gt;Maintainer&lt;/b&gt;: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/aptplugin/packagedescriptionplugin.cpp" line="241"/>
        <source>&lt;b&gt;Maintainer&lt;/b&gt;: not available&lt;br&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/aptplugin/packagedescriptionplugin.cpp" line="243"/>
        <source>&lt;b&gt;Architecture&lt;/b&gt;: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/aptplugin/packagedescriptionplugin.cpp" line="245"/>
        <source>&lt;b&gt;Architecture&lt;/b&gt;: not available&lt;br&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/aptplugin/packagedescriptionplugin.cpp" line="247"/>
        <source>&lt;b&gt;Source&lt;/b&gt;: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/aptplugin/packagedescriptionplugin.cpp" line="251"/>
        <source>&lt;b&gt;Replaces&lt;/b&gt;: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/aptplugin/packagedescriptionplugin.cpp" line="256"/>
        <source>&lt;b&gt;Provides&lt;/b&gt;: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/aptplugin/packagedescriptionplugin.cpp" line="261"/>
        <source>&lt;b&gt;Pre-Depends&lt;/b&gt;: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/aptplugin/packagedescriptionplugin.cpp" line="266"/>
        <source>&lt;b&gt;Depends&lt;/b&gt;: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/aptplugin/packagedescriptionplugin.cpp" line="271"/>
        <source>&lt;b&gt;Recommends:&lt;/b&gt; </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/aptplugin/packagedescriptionplugin.cpp" line="276"/>
        <source>&lt;b&gt;Suggests:&lt;/b&gt; </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/aptplugin/packagedescriptionplugin.cpp" line="281"/>
        <source>&lt;b&gt;Conflicts&lt;/b&gt;: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/aptplugin/packagedescriptionplugin.cpp" line="284"/>
        <source>&lt;b&gt;Filename&lt;/b&gt;: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/aptplugin/packagedescriptionplugin.cpp" line="286"/>
        <source>&lt;b&gt;Filename&lt;/b&gt;: not available&lt;br&gt;
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/aptplugin/packagedescriptionplugin.cpp" line="288"/>
        <source>&lt;b&gt;Size&lt;/b&gt;: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/aptplugin/packagedescriptionplugin.cpp" line="290"/>
        <source>&lt;b&gt;Size&lt;/b&gt;: not available&lt;br&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/aptplugin/packagedescriptionplugin.cpp" line="292"/>
        <source>&lt;b&gt;MD5sum&lt;/b&gt;: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/aptplugin/packagedescriptionplugin.cpp" line="294"/>
        <source>&lt;b&gt;MD5sum&lt;/b&gt;: not available&lt;br&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/aptplugin/packagedescriptionplugin.cpp" line="296"/>
        <source>&lt;b&gt;Conffiles&lt;/b&gt;: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/aptplugin/packagedescriptionplugin.h" line="57"/>
        <source>PackageDescriptionPlugin</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NPlugin::PackageStatusPlugin</name>
    <message>
        <location filename="../src/plugins/aptplugin/packagestatusplugin.cpp" line="19"/>
        <source>Package Status Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/aptplugin/packagestatusplugin.cpp" line="22"/>
        <source></source>
        <translation></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/plugins/aptplugin/aptactionplugin.cpp" line="47"/>
        <source>Reload Package Database</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
